@@ -19,6 +19,8 @@
 
 #include <qobject.h>
 #include <qbuffer.h>
+#include <qlistview.h>
+#include <qtimer.h>
 
 #include <kio/job.h>
 #include <kurl.h>
@@ -29,20 +31,32 @@ Q_OBJECT
 
 public:
 	Monopigator();
+	~Monopigator();
 	void loadData(const KURL &);
 
 signals:
 	void monopigatorAdd(QString host, QString port, QString version, int users);
 	void finished();
+	void timeout();
 
 private slots:
 	void slotData(KIO::Job *, const QByteArray &);
 	void slotResult(KIO::Job *);
+	void slotTimeout();
 
 private:
 	void processData(const QByteArray &, bool = true);
 
 	QBuffer *m_downloadData;
+	QTimer *m_timer;
+	KIO::Job *m_job;
+};
+
+class MonopigatorEntry : public QListViewItem
+{
+public:
+	MonopigatorEntry(QListView *parent, QString host, QString version, QString users, QString port);
+	int compare(QListViewItem *i, int col, bool ascending) const;
 };
 
 #endif
