@@ -7,10 +7,10 @@
 
 
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
-#include <kapp.h>
+#include <kapplication.h>
 
 #include "version.h"
 #include "toplevel.h"
@@ -21,23 +21,20 @@
 
 #include <kaboutdata.h>
 
-#include <X11/Xlib.h> // Has to be last!
-
-
-static const char *description = 
+static const char *description =
 	I18N_NOOP("KDE Space Game");
 
 int main( int argc, char *argv[] )
 {
 
-    KAboutData aboutData( "kasteroids", I18N_NOOP("KAsteroids"), 
-        KASTEROIDS_VERSION, description, KAboutData::License_GPL, 
+    KAboutData aboutData( "kasteroids", I18N_NOOP("KAsteroids"),
+        KASTEROIDS_VERSION, description, KAboutData::License_GPL,
         "(c) 1997, Martin R. Jones");
     aboutData.addAuthor("Martin R. Jones",0, "mjones@kde.org");
     KCmdLineArgs::init( argc, argv, &aboutData );
 
     KApplication app;
-    KGlobal::locale()->insertCatalogue("libkdegames"); 
+    KGlobal::locale()->insertCatalogue("libkdegames");
     KGlobal::dirs()->addResourceType("sprite", KStandardDirs::kde_default("data") + "kasteroids/sprites/");
     KGlobal::dirs()->addResourceType("sounds", KStandardDirs::kde_default("data") + "kasteroids/sounds/");
 
@@ -45,15 +42,13 @@ int main( int argc, char *argv[] )
     // setup mcop communication
     Arts::Dispatcher dispatcher;
 #endif
-    
+
     KAstTopLevel *mainWidget = new KAstTopLevel();
     app.setMainWidget( mainWidget );
     mainWidget->show();
 
     app.exec();
 
-    XAutoRepeatOn( qt_xdisplay() );
-
     return 0;
 }
 
