@@ -4,24 +4,18 @@
  * Part of the KDE project
  */
 
-#include <qaccel.h>
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qlcdnumber.h>
-#include <qpushbutton.h>
 
 #include <kdebug.h>
 #include <kapplication.h>
 #include <kstandarddirs.h>
 #include <kmessagebox.h>
-#include <ktoolbar.h>
 #include <kmainwindow.h>
-#include <kmenubar.h>
 #include <kconfig.h>
 #include <klocale.h>
-#include <kaccel.h>
 #include <kkeydialog.h>
-#include <kiconloader.h>
 #include <kaction.h>
 #include <kstdaction.h>
 #include <kstdgameaction.h>
@@ -265,28 +259,6 @@ KAstTopLevel::KAstTopLevel() : KMainWindow(0)
     powerMeter->setFixedSize( 200, 12 );
     hbd->addWidget( powerMeter );
 
-    accel = new KAccel( this );
-    actions.insert( "Thrust", Thrust );
-    accel->insertItem( i18n("Thrust"), "Thrust", Qt::Key_Up );
-    actions.insert( "RotateLeft", RotateLeft );
-    accel->insertItem( i18n("Rotate Left"), "RotateLeft", Qt::Key_Left );
-    actions.insert( "RotateRight", RotateRight );
-    accel->insertItem( i18n("Rotate Right"), "RotateRight", Qt::Key_Right );
-    actions.insert( "Shoot", Shoot );
-    accel->insertItem( i18n("Shoot"), "Shoot", Qt::Key_Space );
-    actions.insert( "Teleport", Teleport );
-    accel->insertItem( i18n("Teleport"), "Teleport", Qt::Key_Z );
-    actions.insert( "Brake", Brake);
-    accel->insertItem( i18n("Brake"), "Brake", Qt::Key_X );
-    actions.insert( "Shield", Shield );
-    accel->insertItem( i18n("Shield"), "Shield", Qt::Key_S );
-    actions.insert( "Pause", Pause );
-    accel->insertItem( i18n("Pause"), "Pause", Qt::Key_P );
-    actions.insert( "Launch", Launch );
-    accel->insertItem( i18n("Launch"), "Launch", Qt::Key_L );
-
-    accel->readSettings();
-
     initKAction();
 
     setCentralWidget( mainWin );
@@ -300,8 +272,7 @@ KAstTopLevel::KAstTopLevel() : KMainWindow(0)
 #endif
 
     readSettings();
-    
-    applyKeys();
+    slotNewGame();
 }
 
 KAstTopLevel::~KAstTopLevel()
@@ -312,29 +283,29 @@ KAstTopLevel::~KAstTopLevel()
 #endif
 }
 
-void KAstTopLevel::applyKeys()
-{
-   keycodes.clear();
-   for(QMapIterator<QString, Action> it = actions.begin();
-       it != actions.end(); ++it)
-   {
-      QString actionName = it.key();
-      Action a = it.data();
-      int key = accel->shortcut(actionName);
-      keycodes[key] = a;
-   }
-}
-
 void KAstTopLevel::initKAction()
 {
+// game
     KStdGameAction::gameNew( this, SLOT( slotNewGame() ), actionCollection() );
     KStdGameAction::highscores( this, SLOT( slotShowHighscores() ), actionCollection() );
+    KStdGameAction::pause( this, SLOT( slotPause() ), actionCollection() );
     KStdGameAction::quit(this, SLOT( slotQuit() ), actionCollection());
 
-//settings
+// settings
     KStdAction::keyBindings(this, SLOT( slotKeyConfig() ), actionCollection());
     KStdAction::preferences(this, SLOT( slotPref() ), actionCollection());
 
+// keyboard-only actions
+    actionCollection()->setAutoConnectShortcuts(false);
+    keycodes.insert(Thrust, new KAction(i18n("Thrust"), Qt::Key_Up, 0, 0, actionCollection(), "Thrust"));
+    keycodes.insert(RotateLeft, new KAction(i18n("Rotate Left"), Qt::Key_Left, 0, 0, actionCollection(), "RotateLeft"));
+    keycodes.insert(RotateRight, new KAction(i18n("Rotate Right"), Qt::Key_Right, 0, 0, actionCollection(), "RotateRight"));
+    keycodes.insert(Shoot, new KAction(i18n("Shoot"), Qt::Key_Space, 0, 0, actionCollection(), "Shoot"));
+    keycodes.insert(Teleport, new KAction(i18n("Teleport"), Qt::Key_Z, 0, 0, actionCollection(), "Teleport"));
+    keycodes.insert(Brake, new KAction(i18n("Brake"), Qt::Key_X, 0, 0, actionCollection(), "Brake"));
+    keycodes.insert(Shield, new KAction(i18n("Shield"), Qt::Key_S, 0, 0, actionCollection(), "Shield"));
+    keycodes.insert(Launch, new KAction(i18n("Launch"), Qt::Key_L, 0, 0, actionCollection(), "Launch"));
+    
     createGUI("kasteroidsui.rc");
 }
 
@@ -389,14 +360,17 @@ return; // remove this and the above when the sound below is working correctly
 
 void KAstTopLevel::keyPressEvent( QKeyEvent *event )
 {
-    QMapIterator<int, Action> it = keycodes.find( event->key() );
-    if (it == keycodes.end())
+    KKey key(event);
+    Action a = Invalid;
+    QMap<Action, KAction*>::Iterator it = keycodes.begin();
+    for (; it != keycodes.end(); ++it)
     {
-       event->ignore();
-       return;
+       if ( (*it)->shortcut().contains(key) )
+       {
+           a = it.key();
+           break;
+       }
     }
-    Action a = it.data();
-
     switch ( a )
     {
         case RotateLeft:
@@ -412,7 +386,10 @@ void KAstTopLevel::keyPressEvent( QKeyEvent *event )
             break;
 
         case Shoot:
-            view->shoot( true );
+            if (gameOver)
+               slotNewGame();
+            else
+               view->shoot( true );
             break;
 
         case Shield:
@@ -427,6 +404,9 @@ void KAstTopLevel::keyPressEvent( QKeyEvent *event )
             view->brake( true );
             break;
 
+        case Invalid:
+            break;
+
         default:
             event->ignore();
             return;
@@ -436,14 +416,17 @@ void KAstTopLevel::keyPressEvent( QKeyEvent *event )
 
 void KAstTopLevel::keyReleaseEvent( QKeyEvent *event )
 {
-    QMapIterator<int, Action> it = keycodes.find( event->key() );
-    if (it == keycodes.end())
+    KKey key(event);
+    Action a = Invalid;
+    QMap<Action, KAction*>::Iterator it = keycodes.begin();
+    for (; it != keycodes.end(); ++it)
     {
-       event->ignore();
-       return;
+       if ( (*it)->shortcut().contains(key) )
+       {
+           a = it.key();
+           break;
+       }
     }
-    Action a = it.data();
-
     switch ( a )
     {
         case RotateLeft:
@@ -488,14 +471,7 @@ void KAstTopLevel::keyReleaseEvent( QKeyEvent *event )
             }
             break;
 
-        case Pause:
-            {
-                view->pause( true );
-                KMessageBox::information( this,
-                                          i18n("KAsteroids is paused"),
-                                          i18n("Paused") );
-                view->pause( false );
-            }
+        case Invalid:
             break;
 
         default:
@@ -506,14 +482,16 @@ void KAstTopLevel::keyReleaseEvent( QKeyEvent *event )
     event->accept();
 }
 
-void KAstTopLevel::focusInEvent( QFocusEvent * )
+void KAstTopLevel::focusInEvent( QFocusEvent *e )
 {
     XAutoRepeatOff( qt_xdisplay() );
+    KMainWindow::focusInEvent(e);
 }
 
-void KAstTopLevel::focusOutEvent( QFocusEvent * )
+void KAstTopLevel::focusOutEvent( QFocusEvent *e )
 {
     XAutoRepeatOn( qt_xdisplay() );
+    KMainWindow::focusOutEvent(e);
 }
 
 void KAstTopLevel::slotNewGame()
@@ -528,10 +506,11 @@ void KAstTopLevel::slotNewGame()
     view->setRockSpeed( levels[0].rockSpeed );
     view->addRocks( levels[0].nrocks );
     view->showText( i18n( "Press %1 to launch." )
-                    .arg(accel->shortcut("Launch").toString()),
+                    .arg(keycodes[Launch]->shortcut().seq(0).toString()),
                     yellow );
     waitShip = true;
     isPaused = false;
+    gameOver = false;
 }
 
 void KAstTopLevel::slotQuit()
@@ -552,7 +531,7 @@ void KAstTopLevel::slotShipKilled()
     {
         waitShip = true;
         view->showText( i18n( "Ship Destroyed. Press %1 to launch.")
-                        .arg(accel->shortcut("Launch").toString()),
+                        .arg(keycodes[Launch]->shortcut().seq(0).toString()),
                         yellow );
     }
     else
@@ -568,10 +547,20 @@ void KAstTopLevel::slotShipKilled()
         {
            // Show highscore and ask for name.	
            d.exec();
+           slotGameOver();
+        }
+        else
+        {
+           QTimer::singleShot(1000, this, SLOT(slotGameOver()));
         }
     }
 }
 
+void KAstTopLevel::slotGameOver()
+{
+   gameOver = true;
+}
+
 void KAstTopLevel::slotRockHit( int size )
 {
     switch ( size )
@@ -608,8 +597,7 @@ void KAstTopLevel::slotRocksRemoved()
 
 void KAstTopLevel::slotKeyConfig()
 {
-    KKeyDialog::configureKeys( accel, true, this );
-    applyKeys();
+    KKeyDialog::configure( actionCollection(), this );
 }
 
 void KAstTopLevel::slotPref()
@@ -655,3 +643,12 @@ void KAstTopLevel::slotUpdateVitals()
 //    teleportsLCD->display( view->teleportCount() );
     powerMeter->setValue( view->power() );
 }
+
+void KAstTopLevel::slotPause()
+{
+    view->pause( true );
+    KMessageBox::information( this,
+                              i18n("KAsteroids is paused"),
+                              i18n("Paused") );
+    view->pause( false );
+}
