@@ -31,7 +31,6 @@ private:
     void playSound( const char *snd );
     void readSoundMapping();
     void doStats();
-    void applyKeys();
 
 protected:
     virtual void keyPressEvent( QKeyEvent *event );
@@ -42,6 +41,7 @@ protected:
 private slots:
     void readSettings(); // it is useful as a slot
     void slotNewGame();
+    void slotGameOver();
     void slotQuit();
 
     void slotShipKilled();
@@ -54,6 +54,8 @@ private slots:
     void slotPref();
     void slotShowHighscores();
 
+    void slotPause();
+
 private:
     KAsteroidsView *view;
     QLCDNumber *scoreLCD;
@@ -73,18 +75,17 @@ private:
     // waiting for user to press Enter to launch a ship
     bool waitShip;
     bool isPaused;
+    bool gameOver;
 
     int shipsRemain;
     int score;
     int level;
     bool showHiscores;
 
-    enum Action { Launch, Thrust, RotateLeft, RotateRight, Shoot, Teleport,
-                    Brake, Shield, Pause };
+    enum Action { Invalid, Launch, Thrust, RotateLeft, RotateRight, Shoot, 
+                    Teleport, Brake, Shield };
 
-    KAccel *accel;
-    QMap<QString,Action> actions;
-    QMap<int,Action> keycodes;
+    QMap<Action, KAction*> keycodes;
 };
 
 #endif
