@@ -29,7 +29,7 @@ Molek::Molek( QWidget *parent, const char *name ) : QWidget( parent, name )
 {
     data = BarIcon("molek");
     setBackgroundColor (QColor (0, 0, 0));
-    setMinimumSize(200, 200);
+    setMinimumSize(240, 200);
 }
 
 Molek::~Molek ()
@@ -67,21 +67,20 @@ void Molek::load (const KSimpleConfig& config)
            value = "";
 
 	strcpy(current.conn, value.ascii());
-	if (atoms.find(current) != atoms.end()) {
-	    kdWarning() << "OOOPS" << endl;
-	}
+	kdWarning( atoms.find(current) != atoms.end() )
+	  << "OOOPS, duplicate atom definition in " << key << endl;
 	atoms.append(current);
 	atom_index++;
     }
 
     QString line;
 
-    for (int j = 0; j < 10; j++) {
+    for (int j = 0; j < 15; j++) {
 
 	key.sprintf("mole_%d", j);
 	line = config.readEntry(key);
 
-	for (int i = 0; i < 10; i++)
+	for (int i = 0; i < 15; i++)
 	    molek[i][j] = atom2int(line.at(i).latin1());
     }
 
@@ -93,8 +92,8 @@ void Molek::load (const KSimpleConfig& config)
     height = 0;
     width = 0;
 
-    for (int i = 0; i < 10; i++)
-		for (int j = 0; j < 10; j++) {
+    for (int i = 0; i < 15; i++)
+		for (int j = 0; j < 15; j++) {
 			if (molek [i][j] == 0)
 				continue;
 			if (i > width) width = i;
@@ -115,8 +114,8 @@ void Molek::paintEvent( QPaintEvent * )
     paint.drawText (7, height() - 36, mname);
     paint.drawText (7, height() - 18, st);
     // spielfeld gleich zeichnen
-    for (int i = 0; i < 10; i++)
-		for (int j = 0; j < 10; j++) {
+    for (int i = 0; i < 15; i++)
+		for (int j = 0; j < 15; j++) {
 			int x = 10 + i * 15;
 			int y = 10 + j * 15;
 
