@@ -17,7 +17,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-  $Id: kbgfibs.cpp,v 1.12 2002/02/28 07:32:14 hoefkens Exp $
+  $Id: kbgfibs.cpp,v 1.15.2.1 2002/12/06 12:23:21 lunakl Exp $
 
 */
 
@@ -225,8 +225,8 @@ void KBgEngineFIBS::getSetupPages(KDialogBase *nb)
 	/*
 	 * Group boxes
 	 */
-	QGroupBox *gbo = new QGroupBox(i18n("Options:"), w);
-	QGroupBox *gbm = new QGroupBox(i18n("Automatic Messages:"), w);
+	QGroupBox *gbo = new QGroupBox(i18n("Options"), w);
+	QGroupBox *gbm = new QGroupBox(i18n("Automatic Messages"), w);
 
 	gl->addWidget(gbo, 0, 0);
 	gl->addWidget(gbm, 1, 0);
@@ -255,9 +255,9 @@ void KBgEngineFIBS::getSetupPages(KDialogBase *nb)
 	 */
 	gl = new QGridLayout(gbm, NumMsg, 2, 20);
 
-	cbm[MsgBeg] = new QCheckBox(i18n("Start match :"), gbm);
-	cbm[MsgWin] = new QCheckBox(i18n("Win match :"), gbm);
-	cbm[MsgLos] = new QCheckBox(i18n("Lose match :"), gbm);
+	cbm[MsgBeg] = new QCheckBox(i18n("Start match:"), gbm);
+	cbm[MsgWin] = new QCheckBox(i18n("Win match:"), gbm);
+	cbm[MsgLos] = new QCheckBox(i18n("Lose match:"), gbm);
 
 	QWhatsThis::add(cbm[MsgBeg], i18n("If you want to send a standard greeting to your "
 					  "opponent whenever you start a new match, check "
@@ -293,8 +293,8 @@ void KBgEngineFIBS::getSetupPages(KDialogBase *nb)
 	w = new QWidget(tc);
 	gl = new QGridLayout(w, 3, 1, nb->spacingHint());
 
-	QGroupBox *gbc = new QGroupBox(i18n("Server:"), w);
-	QGroupBox *gbk = new QGroupBox(i18n("Other:"), w);
+	QGroupBox *gbc = new QGroupBox(i18n("Server"), w);
+	QGroupBox *gbk = new QGroupBox(i18n("Other"), w);
 
 	gl->addWidget(gbc, 0, 0);
 	gl->addWidget(gbk, 1, 0);
@@ -306,9 +306,9 @@ void KBgEngineFIBS::getSetupPages(KDialogBase *nb)
 
 	QLabel *lbc[NumFIBS];
 
-	lbc[FIBSHost] = new QLabel(i18n("Server Name:"), gbc);
-	lbc[FIBSPort] = new QLabel(i18n("Server Port:"), gbc);
-	lbc[FIBSUser] = new QLabel(i18n("User Name:"), gbc);
+	lbc[FIBSHost] = new QLabel(i18n("Server name:"), gbc);
+	lbc[FIBSPort] = new QLabel(i18n("Server port:"), gbc);
+	lbc[FIBSUser] = new QLabel(i18n("User name:"), gbc);
 	lbc[FIBSPswd] = new QLabel(i18n("Password:"), gbc);
 
 	for (int i = 0; i < NumFIBS; i++) {
@@ -405,7 +405,7 @@ void KBgEngineFIBS::changeJoin(const QString &info)
 	 * Extract the name of the player, her opponent, rating and experience.
 	 * It is okay to use latin1(), since the string is coming from FIBS.
 	 */
-	sscanf(info.latin1(), "%s %s %*s %*s %*s %f %i %*s %*s %*s %*s %*s",
+	sscanf(info.latin1(), "%99s %99s %*s %*s %*s %f %i %*s %*s %*s %*s %*s",
 	       name_p, name_o, &rate, &expi);
 
 	QString name = name_p;
@@ -1431,7 +1431,7 @@ void KBgEngineFIBS::handleMessageConnect(const QString &line, const QString &raw
 		char p[3][256];
 		time_t tmp;
 		// Using latin1() is okay, since the string comes from FIBS.
-		int words = sscanf (line.latin1(), "%s%s%li%s", p[0], p[1], &tmp, p[2]);
+		int words = sscanf (line.latin1(), "%255s%255s%li%255s", p[0], p[1], &tmp, p[2]);
 		if (words >= 4) {
 			QDateTime d; d.setTime_t(tmp);
 			QString text = i18n("%1, last logged in from %2 at %3.").arg(p[1]).arg(p[2]).arg(d.toString());
@@ -1481,7 +1481,7 @@ void KBgEngineFIBS::handleMessageConnect(const QString &line, const QString &raw
 		double rating;
 
 		// Using latin1() is okay, since the string comes from FIBS.
-		int words = sscanf (line.latin1(), "%s%s%i%i%i%i%i%i%i%i%i%i%i%i%i%lf%i%i%i%i%i%s",
+		int words = sscanf (line.latin1(), "%255s%255s%i%i%i%i%i%i%i%i%i%i%i%i%i%lf%i%i%i%i%i%255s",
 				    p[0], p[1],
 				    &fibsOptions[OptAllowPip],
 				    &n[0],
@@ -2195,7 +2195,7 @@ KBgEngineFIBS::KBgEngineFIBS(QWidget *parent, QString *name, QPopupMenu *pmenu)
 
 		fibsOpt[OptReady]   = new KToggleAction(i18n("Ready to Play"),
 							0, this, SLOT(toggle_ready()),   this);
-		fibsOpt[OptRatings] = new KToggleAction(i18n("Show  Rating Computations"),
+		fibsOpt[OptRatings] = new KToggleAction(i18n("Show Rating Computations"),
 							0, this, SLOT(toggle_ratings()), this);
 		fibsOpt[OptGreedy]  = new KToggleAction(i18n("Greedy Bearoffs"),
 							0, this, SLOT(toggle_greedy()),  this);
