@@ -17,7 +17,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-  $Id: kbg.cpp,v 1.24.2.1 2002/12/09 23:27:22 faure Exp $
+  $Id: kbg.cpp,v 1.24.2.4 2003/02/24 18:33:32 binner Exp $
 
 */
 
@@ -121,7 +121,7 @@ KBg::KBg(QWidget *parent, const char *name)
 	KStdGameAction::redo     (this, SLOT(redo()), actionCollection())->setEnabled(false);
 
 	KStdGameAction::roll(this, SLOT(roll()), actionCollection())->setEnabled(false);
-	KStdGameAction::endTurn(this, SLOT(done()), actionCollection())->setEnabled(false);
+	KStdGameAction::endTurn(this, SLOT(done()), actionCollection(), "move_end_turn")->setEnabled(false);
 	(new KAction(i18n("Double Cube"), QIconSet(kapp->iconLoader()->loadIcon
 						   (PROG_NAME "-double.xpm", KIcon::Toolbar)),
 		     0, this, SLOT(cube()), actionCollection(), "move_cube"))->setEnabled(false);
@@ -868,7 +868,7 @@ void KBg::allowCommand(int cmd, bool f)
 		actionCollection()->action("move_cube")->setEnabled(f);
 		break;
 	case KBgEngine::Done:
-		actionCollection()->action("move_endturn")->setEnabled(f);
+		actionCollection()->action("move_end_turn")->setEnabled(f);
 		break;
 	case KBgEngine::Load:
 		actionCollection()->action("move_load")->setEnabled(f);
