@@ -7,26 +7,26 @@
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
-  
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-  $Id: kbg.h,v 1.8 2001/08/16 21:13:25 hoefkens Exp $
-  
+  $Id: kbg.h,v 1.9.2.1 2002/12/09 23:27:22 faure Exp $
+
 */
 
-#ifndef __KBG_H 
-#define __KBG_H 
+#ifndef __KBG_H
+#define __KBG_H
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif 
+#endif
 
 #include <kmainwindow.h>
 #include <ktoolbar.h>
@@ -48,7 +48,7 @@
 class KBg : public KMainWindow
 {
 	Q_OBJECT
-		
+
 public:
 
 	/**
@@ -60,17 +60,17 @@ public:
 	 * Destructor
 	 */
 	virtual ~KBg();
-  
+
 	/**
 	 * Read various settings from the configuration files or
 	 * set some reasonable defaults
-	 */  
+	 */
 	void readConfig();
-	
+
 public slots:
 
          /**
-	 * Set the caption to KFIBS_NAME + string + pipcount (if requested by 
+	 * Set the caption to KFIBS_NAME + string + pipcount (if requested by
 	 * the user)
 	 */
 	void updateCaption(const QString &s);
@@ -113,13 +113,6 @@ protected:
 	 */
 	virtual void showEvent(QShowEvent *);
 
-	/*
-	 * Called before the very last window is closed. Performs a
-	 * proper shutdown of the application -- no user interaction!
-	 * if necessary.
-	 */
-	virtual bool queryExit();
-
 	/*
 	 * Called before the window is closed. Check with the engine
 	 * if that is okay.
@@ -139,6 +132,7 @@ protected slots:
 
 	void configureKeys();
 	void configureToolbars();
+	void newToolbarConfig();
 
 	/**
 	 * Starts the print dialog and asks the board to print itself
@@ -148,7 +142,7 @@ protected slots:
 	void openNew();
 
 	/**
-	 * Takes text from the commandline and hands it over to the 
+	 * Takes text from the commandline and hands it over to the
 	 * current engine
 	 */
 	void handleCmd(const QString &);
@@ -209,7 +203,7 @@ protected slots:
 	void setupCancel();
 
 private:
-	
+
 	/*
 	 * Each engine has its own identifier.
 	 */
@@ -223,7 +217,7 @@ private:
 	QString helpTopic[MaxHelpTopic][2];
 	KSelectAction *engineSet;
 
-	/** 
+	/**
 	 * Notebook for the setup
 	 */
 	KDialogBase *nb;
@@ -239,11 +233,10 @@ private:
 	KBgTextView   *status;
 	KLineEdit     *cmdLine;
 	QLabel        *cmdLabel;
-	QPopupMenu    *menu;
-	
+
 	/*
 	 * Backgammon engine
-	 */	 
+	 */
 };
 
-#endif // __KBG_H 
+#endif // __KBG_H
