@@ -2,28 +2,28 @@
 
   Copyright (C) 1999-2001 Jens Hoefkens
   jens@hoefkens.com
-  
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
-  
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-  
+
 */
 
 
 /*
-  
-  This file contains the declaration and definition of a couple of 
-  classes related to the KBgBoard class. 
+
+  This file contains the declaration and definition of a couple of
+  classes related to the KBgBoard class.
 
   Effort has been made to keep this class general. Please comment on that
   if you want to use it in your own project. Most of the stuff is private
@@ -32,12 +32,12 @@
 
 */
 
-#ifndef KBGBOARD_H 
-#define KBGBOARD_H 
+#ifndef KBGBOARD_H
+#define KBGBOARD_H
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif 
+#endif
 
 #include <qspinbox.h>
 #include <qpushbutton.h>
@@ -50,12 +50,12 @@
 #include <qregexp.h>
 #include <qradiobutton.h>
 #include <qwidget.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qtimer.h>
 #include <qlabel.h>
 #include <qcursor.h>
-#include <qpopupmenu.h> 
-#include <qcombobox.h> 
+#include <qpopupmenu.h>
+#include <qcombobox.h>
 #include <kdialogbase.h>
 #include <kfontdialog.h>
 
@@ -103,16 +103,16 @@ class KBgBoard : public QWidget
 	friend class KBgBoardHome;
 	friend class KBgBoardBar;
 	friend class KBgBoardField;
-		
+
  public:
 
 	/**
 	 * Constructor and destructor. Parameter as usual.
 	 */
-	KBgBoard(QWidget *parent = 0, const char *name = 0, 
+	KBgBoard(QWidget *parent = 0, const char *name = 0,
 			 QPopupMenu *menu = 0);
 	virtual ~KBgBoard();
-	
+
 	/**
 	 * Returns the current read/write status of the board.
 	 */
@@ -120,7 +120,7 @@ class KBgBoard : public QWidget
 
 	/**
 	 * Returns the current up-to-the-second pip count (including
-	 * the moves that have been done. 
+	 * the moves that have been done.
 	 */
 	int getPipCount(const int& w) const;
 
@@ -138,7 +138,7 @@ class KBgBoard : public QWidget
 	int getShortMoveMode();
 
 	/**
-	 * Sets the background color and passes the info to the 
+	 * Sets the background color and passes the info to the
 	 * child widgets
 	 */
 	virtual void setBackgroundColor(QColor col);
@@ -179,7 +179,7 @@ class KBgBoard : public QWidget
 public slots:
 
 	/**
-	 * This allows the users of this widget to dis- and enable 
+	 * This allows the users of this widget to dis- and enable
 	 * mouse events. In effect this triggers the read/write
 	 * flag of the board.
 	 */
@@ -191,7 +191,7 @@ public slots:
 	 * We overwrite the handler to make sure that all the cells are
 	 * repainted as well.
 	 */
-	virtual void resizeEvent(QResizeEvent *);	
+	virtual void resizeEvent(QResizeEvent *);
 
         /**
 	 * Undo the last move.
@@ -205,7 +205,7 @@ public slots:
 
 	/**
 	 * This is the most important public member. It takes
-	 * a board status - s. the KBgBoardStatus class - 
+	 * a board status - s. the KBgBoardStatus class -
 	 * and sets the board accordingly.
 	 */
 	void setState(const KBgStatus &);
@@ -214,7 +214,7 @@ public slots:
 	 * Set the context menu
 	 */
 	void setContextMenu(QPopupMenu *menu);
-	
+
 	/**
 	 * Get the current state of the board.
 	 */
@@ -242,14 +242,14 @@ public slots:
 	 */
 	void readConfig();
 
- signals:	
+ signals:
 
 	/**
 	 * The text identifies the current game status - could be put
 	 * into the main window caption
 	 */
 	void statText(const QString &msg);
-	
+
 	/**
 	 * The cells connect to this signal and it tells them that it is
 	 * time to update their content now if necessary.
@@ -257,7 +257,7 @@ public slots:
 	void finishedUpdate();
 
 	/**
-	 * The user has requested the dice to be rolled. Emit the 
+	 * The user has requested the dice to be rolled. Emit the
 	 * request to somebody who knows how to do that.
 	 */
 	void rollDice(const int w);
@@ -269,7 +269,7 @@ public slots:
 
 	/**
 	 * Once the moves are all made, build a server command and send
-	 * them out. 
+	 * them out.
 	 */
 	void currentMove(QString *s);
 
@@ -325,7 +325,7 @@ protected:
 	void getRollDice(const int w);
 
 	/**
-	 * Tell the board that we kicked a piece off and store 
+	 * Tell the board that we kicked a piece off and store
 	 * the information
 	 */
 	void kickedPiece();
@@ -368,7 +368,7 @@ protected:
 	void makeMove( int src, int dest );
 
 	/**
-	 * Translates a field number to a pointer to the cell. 
+	 * Translates a field number to a pointer to the cell.
 	 */
 	KBgBoardCell* getCell(int num);
 
@@ -376,20 +376,20 @@ protected:
 	 * Draws a piece on the painter p, with the upper left corner
 	 * of the enclosing rectangle being (x,y)
 	 */
-	void drawCircle(QPainter *p, int x, int y, int pcs, int diam, 
+	void drawCircle(QPainter *p, int x, int y, int pcs, int diam,
 			int col, bool upper, bool outer) const;
 
 	/**
-	 * Draws an anti-aliased checker on the painter p. 
+	 * Draws an anti-aliased checker on the painter p.
 	 */
-	void drawChecker(QPainter *p, int x, int y, int pcs, int diam, 
+	void drawChecker(QPainter *p, int x, int y, int pcs, int diam,
 			 int col, bool upper) const;
 
 	/**
 	 * Draws a simple 2-color checker on the painter p. This is intended
 	 * for printing.
 	 */
-	void drawSimpleChecker(QPainter *p, int x, int y, int pcs, 
+	void drawSimpleChecker(QPainter *p, int x, int y, int pcs,
 			       int diam) const;
 
 	/**
@@ -417,17 +417,17 @@ protected:
 	 */
 	QColor getCheckerColor(int p) const;
 
-	/** 
+	/**
 	 * Small utility function for makeMove - just for readability
 	 */
 	int makeMoveHelper(int si, int sf, int delta);
 
-	/** 
+	/**
 	 * Private data members - no description needed
 	 */
 	QPopupMenu *contextMenu;
-	QList<KBgBoardMove> moveHistory;
-	QList<KBgBoardMove> redoHistory;
+	QPtrList<KBgBoardMove> moveHistory;
+	QPtrList<KBgBoardMove> redoHistory;
 	int direction, color;
 	int hasmoved;
 	bool allowmoving, editMode;
@@ -455,7 +455,7 @@ protected:
 class KBgBoardCell : public QLabel
 {
       	Q_OBJECT
-	
+
  public:
 
 	/**
@@ -473,9 +473,9 @@ class KBgBoardCell : public QLabel
 	/**
 	 * Draws the content of the cell on the painter *p
 	 */
-	virtual void paintCell(QPainter *p, int xo = 0, int yo = 0, 
+	virtual void paintCell(QPainter *p, int xo = 0, int yo = 0,
 			       double sf = 1.0) const;
-	
+
 	/**
 	 * Updates all the status variables at once
 	 */
@@ -487,10 +487,10 @@ protected:
 	 * Draw vertical lines around the board.
 	 */
 	void drawVertBorder(QPainter *p, int xo, int yo, double sf = 1.0) const;
-	void drawOverlappingCheckers(QPainter *p, int xo, int yo, 
+	void drawOverlappingCheckers(QPainter *p, int xo, int yo,
 				     double sf = 1.0) const;
 	void drawCube(QPainter *p, int who, int xo, int yo, double sf = 1.0) const;
-	
+
 	/**
 	 * Puts a piece of color on a field
 	 */
@@ -510,15 +510,15 @@ protected:
 	/**
 	 * Return the suggested diameter of a piece
 	 */
-	int getCheckerDiameter() const;	
+	int getCheckerDiameter() const;
 	int getCellColor();
-	
+
 	/**
 	 * Do we allow a drop of the DragEvent ? This checks the payload and
 	 * reacts on it.
 	 */
 	virtual bool dropPossible(int fromCellID, int newColor) = 0;
-	
+
  protected:
 
 	/**
@@ -527,9 +527,9 @@ protected:
 	virtual void drawContents(QPainter *);
 
 	/**
-	 * Status numbers that store the current board status. 
+	 * Status numbers that store the current board status.
 	 */
-	int mouseButton; 	
+	int mouseButton;
 	int direction;
 	int color;
 
@@ -542,9 +542,9 @@ protected:
 	 * Our own ID
 	 */
 	int cellID;
-	
+
 	/**
-	 * Indicates whether this cell needs to repaint itself after 
+	 * Indicates whether this cell needs to repaint itself after
 	 * the board has been processed.
 	 */
 	bool stateChanged;
@@ -567,7 +567,7 @@ protected:
 	 */
 	QRect diceRect(int i, bool big, double sf = 1.0, double scale = 0.45) const;
 	bool dragInProgress;
-	
+
  protected slots:
         /**
 	 * Refreshes the widget. This is essentially a call to update().
@@ -590,7 +590,7 @@ protected:
 	 */
 	void makeShortMove();
 	void makeShortMoveHelper(int s, int d);
-	
+
 	/**
 	 * Catch a single left click and perhapes make a move.
 	 */
@@ -598,18 +598,18 @@ protected:
 
 	/**
 	 * Catch a double left click and perhapes make a move.
-	 */  
-	virtual void mouseDoubleClickEvent( QMouseEvent *e );	
+	 */
+	virtual void mouseDoubleClickEvent( QMouseEvent *e );
 };
 
 /**
- * The homes are derived from the regular cells. They just overwrite 
+ * The homes are derived from the regular cells. They just overwrite
  * some members.
  */
 class KBgBoardHome : public KBgBoardCell
 {
       	Q_OBJECT
-	
+
  public:
 	/**
 	 * sets the number and color of checkers on this cell
@@ -620,7 +620,7 @@ class KBgBoardHome : public KBgBoardCell
 	/*
 	 * Draws the content of the cell on the painter *p
 	 */
-	virtual void paintCell(QPainter *p, int xo = 0, int yo = 0, 
+	virtual void paintCell(QPainter *p, int xo = 0, int yo = 0,
 			       double sf = 1.0) const;
 
 	/**
@@ -629,11 +629,11 @@ class KBgBoardHome : public KBgBoardCell
 	KBgBoardHome( QWidget * parent, int numID);
 	virtual ~KBgBoardHome();
 
-	/** 
+	/**
 	 * Check whether a drop on the home cell is possible.
 	 */
 	virtual bool dropPossible(int fromCellID, int newColor);
-	
+
  protected:
 	/**
 	 * Determine whether a drag from the home is possible.
@@ -648,13 +648,13 @@ class KBgBoardHome : public KBgBoardCell
         /**
 	 * The homes contain dice and cube. This draws them.
 	 */
-        void drawDiceAndCube(QPainter *p, int who, int xo, int yo, 
+        void drawDiceAndCube(QPainter *p, int who, int xo, int yo,
 			      double sf) const;
 
-	void drawDiceFrame(QPainter *p, int col, int num, int xo, int yo, 
+	void drawDiceFrame(QPainter *p, int col, int num, int xo, int yo,
 			   bool big, double sf) const;
-	void drawDiceFace(QPainter *p, int col, int num, int who, int xo, 
-			  int yo, double sf) const;	
+	void drawDiceFace(QPainter *p, int col, int num, int who, int xo,
+			  int yo, double sf) const;
 
  private:
 	/**
@@ -665,13 +665,13 @@ class KBgBoardHome : public KBgBoardCell
 };
 
 /**
- * The bars are derived from the regular cells. They just overwrite 
+ * The bars are derived from the regular cells. They just overwrite
  * some members.
  */
 class KBgBoardBar : public KBgBoardCell
 {
        	Q_OBJECT
-  
+
  public:
 	/**
 	 * sets the number and color of checkers on this cell
@@ -682,7 +682,7 @@ class KBgBoardBar : public KBgBoardCell
 	/**
 	 * Draws the content of the cell on the painter *p
 	 */
-	virtual void paintCell(QPainter *p, int xo = 0, int yo = 0, 
+	virtual void paintCell(QPainter *p, int xo = 0, int yo = 0,
 			       double sf = 1.0) const;
 
 	/**
@@ -695,11 +695,11 @@ class KBgBoardBar : public KBgBoardCell
 	 */
 	virtual ~KBgBoardBar();
 
-	/** 
+	/**
 	 * Check whether a drop on the bar cell is possible.
 	 */
 	virtual bool dropPossible(int fromCellID, int newColor);
-	
+
  protected:
 	/**
 	 * Determine whether a drag from the bar is possible.
@@ -712,13 +712,13 @@ class KBgBoardBar : public KBgBoardCell
 };
 
 /**
- * The fields are derived from the regular cells. They just overwrite 
+ * The fields are derived from the regular cells. They just overwrite
  * some members.
  */
 class KBgBoardField : public KBgBoardCell
 {
 	Q_OBJECT
-	
+
  public:
 	/**
 	 * Constructor and destructor
@@ -735,14 +735,14 @@ class KBgBoardField : public KBgBoardCell
 	/**
 	 * Draws the content of the cell on the painter *p
 	 */
-	virtual void paintCell(QPainter *p, int xo = 0, int yo = 0, 
+	virtual void paintCell(QPainter *p, int xo = 0, int yo = 0,
 			       double sf = 1.0) const;
 
-	/** 
+	/**
 	 * Check whether a drop on the field cell is possible.
 	 */
 	virtual bool dropPossible(int fromCellID, int newColor);
-	
+
  protected:
 	/**
 	 * Determine whether a drag from the field is possible.
@@ -758,7 +758,7 @@ class KBgBoardField : public KBgBoardCell
 /**
  * Internal class for storing a move in the undo history buffer.
  */
-class KBgBoardMove 
+class KBgBoardMove
 {
  public:
 	/**
@@ -771,7 +771,7 @@ class KBgBoardMove
 	/**
 	 * Set this move to be a kick
 	 */
-	void setKicked(bool kicked) {k = kicked;} 
+	void setKicked(bool kicked) {k = kicked;}
 
 	/**
 	 * Look up the source
@@ -792,7 +792,7 @@ class KBgBoardMove
 	 * Check whether the move kicked a piece
 	 */
 	bool wasKicked() const {return k;}
-	
+
  private:
 	/**
 	 * Source, destination, dice
@@ -805,7 +805,7 @@ class KBgBoardMove
 	bool k;
 };
 
-/** 
+/**
  * Simple dialog that allows to query the user for dice values.
  *
  * A very simple dialog with two SpinBoxes and two buttons.
@@ -813,7 +813,7 @@ class KBgBoardMove
 class KBgBoardQDice : public QDialog
 {
 	Q_OBJECT
-	
+
 public:
 
 	/**
@@ -821,7 +821,7 @@ public:
 	 */
 	KBgBoardQDice(const char *name = 0);
 	virtual ~KBgBoardQDice();
-	
+
 protected:
 
 	/**
@@ -839,14 +839,14 @@ public slots:
         int getDice(int n);
 };
 
-  
-/** 
+
+/**
  * Simple dialog that allows to query the user for the cube value.
  */
 class KBgBoardQCube : public QDialog
 {
 	Q_OBJECT
-	
+
 public:
 
 	/**
@@ -854,7 +854,7 @@ public:
 	 */
 	KBgBoardQCube(int val, bool us, bool them);
 	virtual ~KBgBoardQCube();
-	
+
 protected:
 
 	/**
@@ -897,9 +897,9 @@ public:
 	/**
 	 * Constructor
 	 */
-	KBgBoardSetup(QWidget *parent = 0, const char *name = 0, 
+	KBgBoardSetup(QWidget *parent = 0, const char *name = 0,
 			      QPopupMenu *menu = 0);
-	
+
 	/**
 	 * Lets the board put its setup pages into the notebook nb
 	 */
@@ -931,12 +931,12 @@ protected slots:
 
         /**
 	 * Open a color dialog for the first checker color
-	 */	
+	 */
 	void selectBaseColorOne();
 
         /**
 	 * Open a color dialog for the second checker color
-	 */	
+	 */
 	void selectBaseColorTwo();
 
 private:
@@ -957,5 +957,5 @@ private:
 	QPushButton *pbc_1, *pbc_2, *pbc_3;
 	QCheckBox *cbp;
 };
-  
-#endif // KBGBOARD_H 
+
+#endif // KBGBOARD_H
