@@ -23,7 +23,6 @@
 
 
 #include <kapplication.h>
-#include <kglobal.h>
 #include <klocale.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
@@ -31,32 +30,24 @@
 // #include <qimageio.h>
 
 #include "klines.h"
-void dummyMessageHandler( QtMsgType type, const char *msg )
-{
-}
-/*
-#ifndef _DBG_
-#define _DBG_
-#endif
-*/
+
 static const char *description = I18N_NOOP("Kolor Lines - a little game about balls and how to get rid of them");
 
 int main( int argc, char **argv )
 {
 	KAboutData aboutData("klines", I18N_NOOP("Kolor Lines"), LINESVERSION,
 						  description, KAboutData::License_GPL);
-//	 aboutData.addAuthor("Roman Merzlyakov", 0, "roman@sbrf.barrt.ru");
-	 aboutData.addAuthor("Roman Razilov", 0, "Roman.Razilov@gmx.de");
+	 aboutData.addAuthor("Roman Merzlyakov", I18N_NOOP("Original author"), "roman@sbrf.barrt.ru");
+	 aboutData.addAuthor("Roman Razilov", I18N_NOOP("Rewrite and Extension"), "Roman.Razilov@gmx.de");
 	 KCmdLineArgs::init(argc, argv, &aboutData);
 
-#ifndef _DBG_
-  qInstallMsgHandler( dummyMessageHandler );
-#endif
   KApplication a;
   KGlobal::locale()->insertCatalogue("libkdegames");
   KLines *v = new KLines;
 
   a.setMainWidget( v );
   v->show();
-  return a.exec();
+  a.exec();
+  delete v;
+  return 0;
 }
