@@ -75,7 +75,6 @@ HighScore::HighScore
 	qtarch_Label_4->setGeometry( 40, 45, 150, 30 );
 	qtarch_Label_4->setFrameStyle( 50 );
 	qtarch_Label_4->setText( i18n("Name") );
-	qtarch_Label_4->setAlignment( 289 );
 	qtarch_Label_4->setFont(fnt);
 
 
@@ -93,7 +92,6 @@ HighScore::HighScore
 	qtarch_Label_5->setGeometry( 270, 45, 70, 30 );
 	qtarch_Label_5->setFrameStyle( 50 );
 	qtarch_Label_5->setText( i18n("Score") );
-	qtarch_Label_5->setAlignment( 289 );
 	qtarch_Label_5->setFont(fnt);
 
         // time
@@ -102,7 +100,6 @@ HighScore::HighScore
         qtarch_Label_6->setGeometry( 340, 45, 70, 30 );
         qtarch_Label_6->setFrameStyle( 50 );
         qtarch_Label_6->setText( i18n("Time") );
-        qtarch_Label_6->setAlignment( 289 );
         qtarch_Label_6->setFont(fnt); 
 
 
@@ -235,7 +232,7 @@ void HighScore::loadTables(void) {
 			fgets(buff, sizeof(buff), fp);
 			if (buff[strlen(buff)-1] == '\n')
 				buff[strlen(buff)-1] = '\0';
-			t->entries[e].name=buff;
+			t->entries[e].name=QString::fromUtf8(buff,-1);
 		}
 	}	
 
