@@ -12,7 +12,6 @@
 #include "Preferences.h"
 #include "kmessagebox.h"
 #include "kstandarddirs.h"
-#include "kglobal.h"
 #include "klocale.h"
 #include <qfileinfo.h>
 
@@ -215,8 +214,8 @@ void Preview::initialise(const PreviewType type, const char *extension)
 	          break;
 
 	    case theme:
-		     fileSelector = i18n("*.theme|Kmahjongg theme\n");
-		     setCaption(kapp->makeStdCaption(i18n("Choose a Theme")));
+		     fileSelector = i18n("*.theme|KMahjongg theme\n");
+		     setCaption(kapp->makeStdCaption(i18n("Choose Theme")));
 		     selectedFile="";
 
 		     themeLayout="";
@@ -312,7 +311,7 @@ void Preview::load(void) {
                                 NULL,
 				fileSelector,
                                 this,
-                                i18n("Open board layout." ));
+                                i18n("Open Board Layout" ));
     if (  !url.isEmpty() ) {
         selectedFile = url.path();
         drawPreview();
