@@ -1,6 +1,6 @@
 /*
 
-    $Id: kmahjongg.cpp,v 1.70.2.1 2002/12/06 14:07:46 lunakl Exp $
+    $Id: kmahjongg.cpp,v 1.70.2.3 2003/06/22 16:18:48 davec Exp $
 
     kmahjongg, the classic mahjongg game for KDE project
 
@@ -106,7 +106,7 @@ int main( int argc, char** argv )
     aboutData.addAuthor("Mathias Mueller", I18N_NOOP("Original Author"), "in5y158@public.uni-hamburg.de");
     aboutData.addAuthor("David Black", I18N_NOOP("Rewrite and Extension"), "david.black@lutris.com");
     aboutData.addAuthor("Michael Haertjens", I18N_NOOP("Solvable game generation\nbased on algorithm by Michael Meeks in GNOME mahjongg"), "mhaertjens@modusoperandi.com");
-    aboutData.addAuthor("Osvaldo Stark", I18N_NOOP("Tile set contributor and web page maintainer"), "starko@dnet.it", "http://freeweb.dnet.it/kmj/");
+    aboutData.addAuthor("Osvaldo Stark", I18N_NOOP("Tile set contributor and web page maintainer"), "starko@dnet.it");
     KCmdLineArgs::init( argc, argv, &aboutData );
 
     KApplication a;
@@ -759,11 +759,15 @@ BoardWidget::BoardWidget( QWidget* parent )
 {
     setBackgroundColor( QColor( 0,0,0 ) );
 
+    timer = new QTimer(this);
+    connect( timer, SIGNAL(timeout()),
+                 this, SLOT(helpMoveTimeout()) );
     TimerState = Stop;
     gamePaused = false;
     iTimerStep = 0;
     matchCount = 0;
     showMatch = false;
+    showHelp = false;
     MouseClickPos1.e = BoardLayout::depth;     // mark tile position as invalid
     MouseClickPos2.e = BoardLayout::depth;
 
@@ -1216,6 +1220,7 @@ void BoardWidget::helpMove()
     {
 		cheatsUsed++;
         iTimerStep = 1;
+        showHelp = true;
         helpMoveTimeout();
     }
     else
@@ -1236,7 +1241,19 @@ void BoardWidget::helpMoveTimeout()
     }
     // restart timer
     if( iTimerStep++ < 8 )
-        QTimer::singleShot( ANIMSPEED, this, SLOT( helpMoveTimeout() ) );
+      timer->start( ANIMSPEED , true);
+    else
+      showHelp = false;
+}
+// ---------------------------------------------------------
+
+void BoardWidget::helpMoveStop()
+{
+  timer->stop();
+  iTimerStep = 8;
+  hilightTile( TimerPos1, false, false );
+  hilightTile( TimerPos2, false );
+  showHelp = false;
 }
 
 // ---------------------------------------------------------
@@ -2231,6 +2248,9 @@ void BoardWidget::mousePressEvent ( QMouseEvent* event )
             stopMatchAnimation();
         }
 
+	if( showHelp ) // stop hilighting tiles
+	  helpMoveStop();  
+
         if( MouseClickPos1.e == BoardLayout::depth )       // first tile
         {
             transformPointToPosition( event->pos(), MouseClickPos1 );
