@@ -69,7 +69,7 @@ GameBoard::GameBoard( QWidget *parent )
     splashScreen->setPixmap(QPixmap(IMAGE_SPLASH));
     splashScreen->setGeometry( 0, 0, 600, 550 );
 
-    setFixedSize( 600, 550 );
+    setMinimumSize( 600, 550 );
 
     setMouseTracking( true );
     setFocusPolicy( StrongFocus );
@@ -330,6 +330,11 @@ GameBoard::nextTurn( void )
 
     scanForSurvivors();
 
+    // advance to first living player
+    while( currentPlayer->current() && !currentPlayer->current()->isInPlay() ) {
+    	++(*currentPlayer);
+    };
+
     // advance turn counter
     turnNumber++;
 
@@ -586,7 +591,7 @@ GameBoard::shutdownGame()
         return;
 
     ScoreDlg *scoreDlg = new ScoreDlg( this, i18n("Final Standings"), &players );
-    scoreDlg->show();
+    scoreDlg->exec();
 
     cleanupGame();
 }
@@ -727,7 +732,7 @@ GameBoard::changeGameBoard( bool inPlay  )
 void
 GameBoard::nextPlayer()
 {
-    // wnd turn and advance to next player
+    // end turn and advance to next player
     Player *plr;
 
     while( (plr = ++(*currentPlayer)) && !(plr->isInPlay()) ) {}
@@ -775,7 +780,7 @@ GameBoard::measureDistance()
     default:
         break;
     }
-};
+}
 
 void
 GameBoard::showScores()
