@@ -28,6 +28,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <qtimer.h>
+#include "cardmaps.h"
 
 #include <freecell-solver/fcs_user.h>
 
@@ -50,7 +51,7 @@ FreecellBase::FreecellBase( int decks, int stores, int freecells, int fill, bool
 solver_instance(0), es_filling(fill), solver_ret(FCS_STATE_NOT_BEGAN_YET),
 unlimited_move(unlimit)
 {
-    deck = new Deck(0, this, decks);
+    deck = Deck::new_deck(this, decks);
     deck->hide();
 
     kdDebug(11111) << "cards " << deck->cards().count() << endl;
@@ -499,6 +500,27 @@ void FreecellBase::waitForMoving(Card *c)
     startMoving();
 }
 
+bool FreecellBase::cardDblClicked(Card *c)
+{
+    // target move
+    if (Dealer::cardDblClicked(c))
+        return true;
+
+    if (c->animated())
+        return false;
+
+    if (c == c->source()->top() && c->realFace())
+        for (uint i = 0; i < freecell.count(); i++)
+            if (freecell[i]->isEmpty()) {
+                CardList empty;
+                empty.append(c);
+                c->source()->moveCards(empty, freecell[i]);
+                canvas()->update();
+                return true;
+            }
+    return false;
+}
+
 bool FreecellBase::CanPutStore(const Pile *c1, const CardList &c2) const
 {
     int fcs, fss;
@@ -573,13 +595,15 @@ Freecell::Freecell( KMainWindow* parent, const char* name)
     : FreecellBase(1, 8, 4, FCS_ES_FILLED_BY_ANY_CARD, false, parent, name)
 {
     for (int i = 0; i < 8; i++)
-        store[i]->move(8+80*i, 113);
+        store[i]->move(8 + ( cardMap::CARDX() * 11 / 10 + 1 ) * i, 8 + cardMap::CARDY() * 11 / 10);
+
+    const int right = 8 + ( cardMap::CARDX() * 11 / 10 + 1 ) * 7 + cardMap::CARDX();
 
     for (int i = 0; i < 4; i++)
-        freecell[i]->move(8+76*i, 8);
+        freecell[i]->move(8 + ( cardMap::CARDX() * 13 / 12 ) * i, 8);
 
     for (int i = 0; i < 4; i++)
-        target[i]->move(338+76*i, 8);
+        target[i]->move(right - (3-i) * ( cardMap::CARDX() * 13 / 12 ) -cardMap::CARDX()  , 8);
 }
 
 void Freecell::deal()
