@@ -62,6 +62,9 @@ public:
 	  * Sets held = true if it is false or false if it is true
 	 **/
 	bool        toggleHeld(); /* returns the new value of held*/
+
+	void repaintDeck();
+	
 	QLabel      *heldLabel;
 	
 protected slots:
@@ -87,10 +90,7 @@ public:
 	CardImages( QWidget *parent = 0, const char *name = 0 ); 
 	~CardImages();
 
-	/**
-	  * This loads all cards
- 	 **/	
-	bool        loadCards();
+//	bool        loadCards();
 	
 	QPixmap     *cardP;
 	QPixmap     deck;
