@@ -39,6 +39,7 @@ Player::~Player()
 {
  delete[] card;
  delete[] foundCards;
+ delete[] cardHelp;
 }
 
 void Player::giveCardsBack()
@@ -311,8 +312,9 @@ int Player::testStraight()
  for (int i = 0; i < CARDS; i++)
 	addFoundCard(i, card[i]);
 
- if (lowest == 0)
-	return 2; // could be a royal flush :-o
+ if (lowest == 0 && findCardTypes(cardTypes, 4)) { // Ace and 10
+	return 2; // a royal flush :-o
+ }
  return 1;
 }
 
