@@ -131,12 +131,12 @@ private slots:
   void gravity(int, bool);
 
 private: // functions
-  bool loadTiles(float scale = 1.0);
+  bool loadTiles(double scale = 1.0);
   void initBoard();
 
   void setField(int x, int y, int value);
   int  getField(int x, int y);
-  void updateField(int, int);
+  void updateField(int, int, bool erase = true);
   QPixmap *lighten(QPixmap *src);
   bool canMakePath(int x1, int y1, int x2, int y2);
   bool findPath(int x1, int y1, int x2, int y2);
@@ -165,6 +165,8 @@ private:
   int _y_tiles;
   int _delay;
   int _shuffle;
+  QSize unscaled_tile;
+  double current_scale;
 
   bool paused;
   time_t pause_start;
