@@ -2,9 +2,12 @@
 #include "board.moc"
 
 #include "common/misc_ui.h"
+#include "common/factory.h"
 #include "piece.h"
 
 
+using namespace Grid2D;
+
 KSBoard::KSBoard(bool graphic, QWidget *parent)
 : Board(graphic, new GiftPool(parent), parent),
   filled(matrix().height()), linesRemoved(4)
@@ -16,14 +19,14 @@ void KSBoard::copy(const GenericTetris &g)
 	filled = static_cast<const KSBoard &>(g).filled.copy(); // deep copy
 }
 
-void KSBoard::init(const GTInitData &data)
+void KSBoard::start(const GTInitData &data)
 {
-	Board::init(data);
 	addRemoved = 0;
     for (uint i=0; i<4; i++) {
         linesRemoved[i] = 0;
         emit removedLinesUpdated(i, 0);
     }
+    Board::start(data);
 }
 
 void KSBoard::computeInfos()
@@ -47,7 +50,7 @@ bool KSBoard::needRemoving()
 
 bool KSBoard::toBeRemoved(const Coord &c) const
 {
-    return ( filled[c.j]==matrix().width() );
+    return ( filled[c.second]==matrix().width() );
 }
 
 void KSBoard::remove()
@@ -63,6 +66,8 @@ void KSBoard::remove()
     emit removedLinesUpdated(nbFullLines-1, linesRemoved[nbFullLines-1]);
 	addRemoved += nbFullLines;
 
+    if ( isArcade() ) return;
+
 	// Assign score according to level and nb of full lines (gameboy style)
 	switch (nbFullLines) {
 	 case 0: break;
@@ -72,16 +77,15 @@ void KSBoard::remove()
 	 case 4: updateScore( score() + 1200 * level() ); break;
 	}
 
-	// increase level every 10 lines
-    if ( nbRemoved()>=level()*10 ) updateLevel(level()+1);
+    updateLevel();
 }
 
 bool KSBoard::toFall(const Coord &c) const
 {
-    return ( filled[c.j-1]==0 );
+    return ( filled[c.second-1]==0 );
 }
 
-/*****************************************************************************/
+//-----------------------------------------------------------------------------
 // Multiplayers methods
 uint KSBoard::gift()
 {
@@ -90,6 +94,13 @@ uint KSBoard::gift()
 	return g;
 }
 
+void KSBoard::setGarbageBlock(const Coord &c)
+{
+   Block *gb = currentPiece()->garbageBlock();
+   gb->sprite()->show();
+   setBlock(c, gb);
+}
+
 bool KSBoard::_putGift(uint nb)
 {
 	if ( nbClearLines()==0 ) return false;
@@ -110,9 +121,7 @@ bool KSBoard::_putGift(uint nb)
 		i = randomGarbage.getLong(matrix().width());
         Coord c(i, 0);
 		if ( matrix()[c]!=0 ) continue;
-		Block *gb = currentPiece()->garbageBlock();
-		gb->sprite()->show();
-		setBlock(c, gb);
+        setGarbageBlock(c);
 		_nb--;
 	} while ( _nb!=0 );
 
@@ -128,3 +137,37 @@ bool KSBoard::putGift(uint nb)
 	return true;
 }
 
+
+//-----------------------------------------------------------------------------
+const KSBoard::StageData KSBoard::STAGE_DATA[Nb_Stages] = {
+    { 4,  1, false, { 0,  0,  0,  0,  0,  0,  0,  0,  0,  0}},
+    { 10, 1, false, { 0,  0,  0,  0,  0,  0,  0,  0,  0,  0}},
+    { 20, 1, false, { 0,  0,  0,  0,  0,  0,  0,  0,  0,  0}},
+
+    // 10 blocks on each sides
+    { 10, 2, true,  {10,  0,  0,  0,  0,  0,  0,  0,  0, 10}},
+    // 10 blocks height triangle
+    { 15, 2, true,  { 0,  2,  4,  7, 10, 10,  7,  4,  2,  0}},
+    // 10 blocks height opposed triangle
+    { 20, 2, true,  {10,  7,  4,  2,  0,  0,  2,  4,  7, 10}}
+};
+
+uint KSBoard::normalTime() const
+{
+    if ( !isArcade() ) return Board::normalTime();
+    return cfactory->cbi.baseTime / (1 + stageData().speed);
+}
+
+void KSBoard::arcadePrepare()
+{
+    if ( !stageData().hasPattern ) return;
+
+    for (uint i=0; i<Width; i++) {
+        Q_ASSERT( stageData().pattern[i]<=matrix().height() );
+        for (uint j=0; j<stageData().pattern[i]; j++)
+            setGarbageBlock(Coord(i, j));
+    }
+    main->update();
+}
+
+
