@@ -5,18 +5,19 @@
 
 #include <klocale.h>
 
-#include "base/defines.h"
+#include "generic/gmisc_ui.h"
 #include "base/board.h"
 
 
 KSField::KSField(QWidget *parent)
     : Field(parent)
 {
-    QWhatsThis::add(showRemoved, i18n("Display the number of lines removed "
+    QWhatsThis::add(removedList, i18n("Display the number of lines removed "
                                       "simultaneously."));
     for (uint i=0; i<4; i++) {
-        showRemoved->append(new LCD(5, showRemoved));
-        showRemoved->lcd(i)->setLeadString(QString::number(i+1));
+        KGameLCD *lcd = new KGameLCD(5, removedList);
+        removedList->append(lcd);
+        lcd->setLeadingString(QString::number(i+1));
     }
 
     connect(board, SIGNAL(removedLinesUpdated(uint, uint)),
@@ -26,6 +27,7 @@ KSField::KSField(QWidget *parent)
 void KSField::removedLinesUpdated(uint i, uint removed)
 {
     Q_ASSERT( i<4 );
-    showRemoved->lcd(i)->showValue(removed);
-    if (removed) showRemoved->lcd(i)->highlight();
+    KGameLCD *lcd = static_cast<KGameLCD *>(removedList->lcd(i));
+    lcd->displayInt(removed);
+    if (removed) lcd->highlight();
 }
