@@ -84,8 +84,8 @@ private:
 
 	void playSound(Sound s);
 	void loadSprites();
-	void loadSprite(Sprite spr, const char *path);
-	void loadMaskedSprite(Sprite spr, const char *path1, const char *path2);
+	void loadSprite(Sprite spr, const QString & path);
+	void loadMaskedSprite(Sprite spr, const QString & path1, const QString & path2);
 	void newBlock();
 	void putPiece();
 	void getPiece();
