@@ -1,9 +1,6 @@
 #ifndef BALL_H
 #define BALL_H
 
-#include <qpixmap.h>
-#include <qwidget.h>
-
 #include "board.h"
 #include "pixServer.h"
 
