@@ -4,9 +4,9 @@
 #include <qimage.h>
 #include <qbitmap.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 
 #include "levels.h"
 
