@@ -2,7 +2,7 @@
 #define RATTLER_H
 
 #include <qwidget.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qbitarray.h>
 
 #include "board.h"
@@ -73,6 +73,7 @@ protected:
     void  timerEvent( QTimerEvent * );
     void  paintEvent( QPaintEvent * );
     void  keyPressEvent( QKeyEvent * );
+    void  mousePressEvent( QMouseEvent * );
     void  focusOutEvent( QFocusEvent * ) { ; }
     void  focusInEvent( QFocusEvent * )  { ; }
 private:
@@ -94,12 +95,12 @@ private:
     Basket    *basket;
     SamySnake *samy;
 
-    QList<Ball> *balls;
+    QPtrList<Ball> *balls;
     void restartBalls(bool);
     int numBalls;
 	int ballsAI;
 
-    QList<CompuSnake> *computerSnakes;
+    QPtrList<CompuSnake> *computerSnakes;
     void restartComputerSnakes(bool);
     int numSnakes;
 	int snakesAI;
