@@ -3,9 +3,11 @@
 
 #include <qwidget.h>
 
-#include "trys.h"
-#include "progress.h"
-#include "rattler.h"
+class QLCDNumber;
+class Trys;
+class Progress;
+class Rattler;
+
 
 class View : public QWidget
 {
@@ -26,5 +28,4 @@ private:
 
 };
 
-
 #endif // VIEW_H
