@@ -21,17 +21,17 @@
 
 #include <kapplication.h>
 #include <kimageio.h>
-#include <kfiledialog.h>
 #include <klocale.h>
+#include <kglobal.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 
 #include "ktron.h"
 #include "version.h"
 
-static const char *description = I18N_NOOP("A race in the hyperspace");
+static const char *description = I18N_NOOP("A race in hyperspace");
 static const char *notice = I18N_NOOP("(c) 1998-2000, Matthias Kiefer\n\n"
-"Parts of the algorithms for the computerplayer are from\n"
+"Parts of the algorithms for the computer player are from\n"
 "xtron-1.1 by Rhett D. Jacobs <rhett@hotel.canberra.edu.au>");
 
 
@@ -42,8 +42,8 @@ int main(int argc, char* argv[])
   aboutData.addAuthor("Matthias Kiefer",0, "matthias.kiefer@gmx.de");
   KCmdLineArgs::init( argc, argv, &aboutData );
 
+  
   KApplication a;
-
   KGlobal::locale()->insertCatalogue("libkdegames");
 
   // used for loading background pixmaps
