@@ -16,11 +16,9 @@
  ***************************************************************************/
 
 // include files for Qt
-#include <qpainter.h>
 #include <stdio.h>
 
 #include <klocale.h>
-#include <kmessagebox.h>
 #include <math.h>
 
 // application specific includes
@@ -359,6 +357,12 @@ void Kwin4View::drawIntro(bool remove)
         move->setDir(false);
         sprite->setFrame(((no-1)/2)%2);
       }
+      // Increase the nz coord for consecutive peices
+      // to allow proper intro
+      // Carefule: The number must be more then the
+      // z coord of [empty] and less than [empty2]
+      sprite->setZ(sprite->z()+no/2);
+      // kdDebug() << "Z("<<no<<")="<<sprite->z()<<endl;
       sprite->show();
     }
   }
@@ -558,9 +562,9 @@ bool Kwin4View::wrongPlayer(KPlayer *player,KGameIO::IOMode io)
     QString m;
     m=QString("text%1").arg(rnd);
     QString ms;
-    if (rnd==1)      ms=i18n("Hold on..the other was not yet gone..."); 
+    if (rnd==1)      ms=i18n("Hold on... the other player has not been yet..."); 
     else if (rnd==2) ms=i18n("Hold your horses..."); 
-    else if (rnd==3) ms=i18n("Ah ah ah...only one go at a time..."); 
+    else if (rnd==3) ms=i18n("Ah ah ah... only one go at a time..."); 
     else             ms=i18n("Please wait... it is not your turn."); 
 
     // TODO MH can be unique
