@@ -18,7 +18,7 @@
     Boston, MA 02111-1307, USA.
 */
 /*
-    $Id: kgamepropertyhandler.cpp,v 1.28 2002/01/25 18:34:46 heni Exp $
+    $Id: kgamepropertyhandler.cpp,v 1.30 2002/05/27 18:32:30 coolo Exp $
 */
 
 #include "kgamepropertyhandler.h"
@@ -27,7 +27,6 @@
 
 #include <qmap.h>
 #include <qptrqueue.h>
-#include <qtimer.h>
 
 #include <klocale.h>
 #include <typeinfo>
@@ -293,7 +292,7 @@ void KGamePropertyHandler::unlockDirectEmit()
   if (d->mIndirectEmit<=0)
   {
     KGamePropertyBase *prop;
-    while(prop=d->mSignalQueue.dequeue())
+    while((prop=d->mSignalQueue.dequeue()) != 0)
     {
       // kdDebug(11001) << "emmiting signal for " << prop->id() << endl;
       emit signalPropertyChanged(prop);
