@@ -17,7 +17,7 @@
 /*
     Networkdlg.cpp
 
-    $Id: networkdlg.cpp,v 1.6 2002/01/04 20:57:10 binner Exp $
+    $Id: networkdlg.cpp,v 1.9 2002/07/09 08:43:42 binner Exp $
     
     Confiugre game over IP
     
@@ -47,12 +47,12 @@ NetworkDlg::NetworkDlg( QWidget *parent, const char *name,const char * /*sufi*/
   QLabel *Label;
   QPushButton *PushButton;
 
-  setCaption(i18n("Configure Network Options..."));
+  setCaption(i18n("Configure Network Options"));
   setMinimumSize(330,260);
   setMaximumSize(330,260);
   resize( 330, 260 );
 
-  grp = new QGroupBox(i18n("Remote settings"), this);
+  grp = new QGroupBox(i18n("Remote Settings"), this);
   grp->resize(290,175);
   grp->move(20,10);
 
@@ -76,8 +76,8 @@ NetworkDlg::NetworkDlg( QWidget *parent, const char *name,const char * /*sufi*/
 
   Label=new QLabel(grp,"Label_3");
   Label->setGeometry(10,95,270,75);
-  Label->setText(i18n("You can leave the remote host input "
-  "empty.\nThen your computer acts as server only and\ndoes not "
+  Label->setText(i18n("You can leave the remote host entry "
+  "empty.\nYour computer then acts as a server only and\ndoes not "
   "try to connect to a remote host."));
 
 
